@@ -1,4 +1,5 @@
 """Decoder abstractions and functions for decoding/converting a string with a given annotation to a dictionary."""
+import functools
 import json
 import logging
 import sys
@@ -7,8 +8,8 @@ import jwt
 LOGGER = logging.getLogger()
 LOGGER.setLevel(logging.INFO)
 
-DECODE_FUNC_NAME = 'decode_%s'
-DECODE_FUNC_MISSING_ERROR = 'Missing decode function for annotation: %s'
+DECODE_FUNC_NAME = "decode_%s"
+DECODE_FUNC_MISSING_ERROR = "Missing decode function for annotation: %s"
 
 
 def decode(annotation, value):
@@ -21,6 +22,7 @@ def decode(annotation, value):
          annotation     decoder
           [json]      decode_json
           [jwt]       decode_jwt
+           [n]        where n is a number. Decodes the value as an array, and picks item n from the array
 
     Args:
         annotation (str): the type of encoding of the value (e.g. 'json', 'jwt').
@@ -30,6 +32,9 @@ def decode(annotation, value):
         decoded dictionary.
     """
     if annotation:
+        if annotation.isdigit():
+            return value[int(annotation)]
+
         module_name = sys.modules[__name__]
         func_name = DECODE_FUNC_NAME % annotation
         if hasattr(module_name, func_name):
@@ -41,11 +46,13 @@ def decode(annotation, value):
     return value
 
 
+@functools.lru_cache()
 def decode_json(value):
     """Convert a json to a dictionary."""
     return json.loads(value)
 
 
+@functools.lru_cache()
 def decode_jwt(value):
     """Convert a jwt to a dictionary."""
     return jwt.decode(value, verify=False)
